<?php

// don't load directly
defined( 'ABSPATH' ) || exit;


/*-----------------------------------------------------------------------------------*/
/*  *.  Anzu License
/*-----------------------------------------------------------------------------------*/

 class AnzuLicense {
	private $anzu_license_options;

	public function __construct() {
		add_action( 'admin_menu', array( $this, 'anzu_license_add_plugin_page' ) );
		add_action( 'admin_init', array( $this, 'anzu_license_page_init' ) );
	}

	public function anzu_license_add_plugin_page() {
		add_submenu_page(
            'anzu',                            // parent slug
            esc_html__( 'License', 'anzu' ),   // page title
            esc_html__( 'License', 'anzu' ),   // menu title
            'manage_options',                            // capability
            'anzu-license.php',                    // slug
            array( $this, 'anzu_license_create_admin_page' )  // function
        );
	}

	public function anzu_license_create_admin_page() {
		$this->anzu_license_options = get_option( 'anzu_license_option_name' ); ?>

		<div class="wrap">
			<h2><?php echo esc_html( 'License', 'anzu' ) ?></h2>
			<?php settings_errors(); ?>

			<form method="post" action="options.php">
				<?php
					settings_fields( 'anzu_license_option_group' );
					do_settings_sections( 'anzu-license-admin' );
					submit_button();
				?>
			</form>
		</div>
	<?php }

	public function anzu_license_page_init() {
		register_setting(
			'anzu_license_option_group', // option_group
			'anzu_license_option_name', // option_name
			array( $this, 'anzu_license_sanitize' ) // sanitize_callback
		);

		add_settings_section(
			'anzu_license_setting_section', // id
			'', // title
			array( $this, 'anzu_license_section_info' ), // callback
			'anzu-license-admin' // page
		);

		add_settings_field(
			'anzu_license_key', // id
			'Anzu License Key', // title
			array( $this, 'anzu_license_key_callback' ), // callback
			'anzu-license-admin', // page
			'anzu_license_setting_section' // section
		);
	}

	public function anzu_license_sanitize($input) {
		$sanitary_values = array();
		if ( isset( $input['anzu_license_key'] ) ) {
			$sanitary_values['anzu_license_key'] = sanitize_text_field( htmlspecialchars( $input['anzu_license_key'] ) );
		}

		return $sanitary_values;
	}

	public function anzu_license_section_info() {
		
	}

	public function anzu_license_key_callback() {

        $anzu_license = isset( $this->anzu_license_options['anzu_license_key'] ) ? $this->anzu_license_options['anzu_license_key'] : '';

		printf(
			'<input class="regular-text" type="text" name="anzu_license_option_name[anzu_license_key]" id="anzu_license_key" value="%s">',
			isset( $anzu_license ) ? esc_attr( $anzu_license ) : ''
		);

        if (strlen($anzu_license) == 40 && preg_match('/\d/', $anzu_license) && preg_match('/[a-zA-Z]/', $anzu_license)) {
            echo "<p>".esc_html( 'Activated', 'anzu' )."</p>";
        } else {
			echo "<p>".esc_html( 'Deactivated', 'anzu' )."</p>";
        }

	}

}
if ( is_admin() )
	$license = new AnzuLicense();
